@@ -4,14 +4,25 @@
 #' @title Creates a Region object
 #' @description This creates an instance of the Region class which defines the study
 #' area for the survey.
+#' @details The strata names should be provided in the order the strata are
+#' presented in the shapefile or sf shape object. This can be simply checked 
+#' after creating the region by plotting it and checking that the key correctly
+#' identifies the strata. Note that the order Distance for Windows displays the
+#' strata in sometimes differs from the order in which they are stored in the
+#' shapefile. IF running from Distance for Windows then this will be checked 
+#' and if they don't match a warning will be displayed saying that they are
+#' being re-ordered.
 #' @param region.name the region name
-#' @param strata.name the stratum names (character vector, same length as the
+#' @param strata.name the strata names (character vector, same length as the
 #'   number of areas in the shapefile / sf object). If not supplied "A", "B",
-#'   "C", ... will be assigned.
+#'   "C", ... will be assigned. The strata names should be provided in the 
+#'   order they appear in the shapefile. See details.
 #' @param units measurement units; either \code{"m"} for metres or \code{"km"} for
 #'   kilometres. If the shapefile has a projection file associated with it the units
 #'   will be taken from there.
 #' @param shape shapefile path to .shp file or an sf object of class sf, sfc or sfg.
+#' @param dist.for.win logical indicating if the region is being created via
+#' Distance for Windows (default = FALSE). See details.
 #' @return object of class Region
 #' @export
 #' @author Laura Marshall
@@ -46,7 +57,8 @@
 make.region <- function(region.name = "region",
                         strata.name = character(0),
                         units = character(0),
-                        shape = NULL){
+                        shape = NULL,
+                        dist.for.win = FALSE){
   #Process shape
   if(inherits(shape, "sf")){
     sf.shape = shape
@@ -93,7 +105,7 @@ make.region <- function(region.name = "region",
     }
   }
   # Check the format of the shape
-  sf.shape <- check.shape(sf.shape)
+  sf.shape <- check.shape(sf.shape, dist.for.win = dist.for.win)
   # Call to make the region object
   region <- new(Class="Region", region.name = region.name, strata.name = strata.name, units = units, sf.shape = sf.shape)
   return(region)
@@ -137,7 +149,14 @@ make.region <- function(region.name = "region",
 #' placed full width lines), "systematic" (systematically placed full width lines),
 #' "eszigzag" (equally spaced zigzag lines), "eszigzagcom" (two sets of complementary
 #' equally spaced zigzag lines) or "segmentedgrid" (a grid of short line transect
-#' segments). If the user specifies "random", they should provide the either the
+#' segments). Note that users may also select a "segmentedtrack" design but dssd 
+#' does not generate transects from this design. This addition was made so that 
+#' simulations can be run from Distance for Windows using this design. In this
+#' case, the transect shapefiles will be generated by Distance for Windows for
+#' use in the simulation. dssd provides this design as an option to allow the 
+#' design specifications to be stored within the simulation.
+#' 
+#' If the user specifies a "random" design, they should provide the either the
 #' number of samplers they wish the design to generate or the line length they wish
 #' to achieve, either by strata or as a total. If the user specifies "systematic"
 #' they should specify either the number of samplers, the desired line length or
@@ -157,7 +176,8 @@ make.region <- function(region.name = "region",
 #' The design angle for the zigzag designs refers to the angle of a line which
 #' would run through the middle of each zigzag transect if the zigzags were to
 #' be generated within a rectangle. The design angle for zigzags should usually
-#' run along the longest dimension of the study region.
+#' run along the longest dimension of the study region. A segmented trackline 
+#' design requires the same specified values as the segmented grid design.
 #'
 #' NOTE: If multiple global design effort arguments are supplied (i.e. spacing,
 #' samplers, line.length) then only the first of spacing then line.length then
@@ -344,7 +364,7 @@ make.design <- function(region = make.region(), transect.type = "line", design =
   }
   if(transect.type %in% c("Line", "line", "Line Transect", "line transect")){
     #Create line transect object
-    if(any(design == "segmentedgrid")){
+    if(any(design %in% c("segmentedgrid","segmentedtrack"))){
       if(length(seg.threshold) == 0){
         seg.threshold <- 50
       }
